###R-code for data analysis:  Nudge for Good? Choice Defaults and Spillover Effects###
###For questions please contact: claus.ghesla@econ.gess.ethz.ch###

# Set your working directory ----------------------------------------------
#path according to where you stored the main data file
setwd("~/_Drive_H/ETH/Papers/Moral Lic. Defaults/3_write_up/3_frontiers_submission/Data&Code")

# Loading R Packages ----------------------------------------------------------------
#Note: not all packages are explicitly needed for the analysis
install.packages("pastecs")
library(pwr)
library(MatchIt)
library(censReg)
library(GGally)
library(VGAM)
library(grid)
library(car)
library(plyr)
library(clinfun)
library(ggplot2)
library(pastecs)
library(pgirmess)
library(survey)
library(PMCMR)
library(WRS2)
library(reshape)
library(ez)
library(nlme)
library(compute.es)
library(multcomp)
library(MASS)
library(Hmisc)
library(gridExtra)
library(QuantPsyc)
library(lme4)
library(mlogit)
library(GGally)
library(VGAM)
library(censReg)
library(boot)
library(AER)
library(gmodels)
library(arules)
library(Exact)
library(fmsb)
library(psych)
library(psy)
library(binom)
library(tidyr)
library(aod)
library(plm)
library(poLCA)
library(directlabels)
library(sandwich)
library(stargazer)
library(rms)
library(Zelig)
library(clusterSEs)
library(lmtest)
library(reshape2)
library(foreign)
library(readstata13)
library(clinfun)
library(gridExtra)
library(QuantPsyc)
library(VGAM)
library(arules)
library(Exact)
library(aod)
library(plm)
library(rockchalk)
library(pscl)
library(truncreg)
library(mhurdle)
library(Hmisc)
library(contrast)

# Preparation of Data-----------------------------------------------------
#Read data
ALL_wide<-read.csv("/SERVER/home/ghesla/_Drive_H/ETH/Papers/3_Frontiers_submission/Data&Code/180726_NudgeforGood_Data.csv", header=TRUE,sep=";")
#check variable names
names(ALL_wide)
#check observations, n=678
nrow(ALL_wide)

#Recode questionnaire items, if reverse-coded
#Big5#
ALL_wide$E2 <- 6-ALL_wide$E2
ALL_wide$A2 <- 6-ALL_wide$A2
ALL_wide$C2 <- 6-ALL_wide$C2
ALL_wide$N2 <- 6-ALL_wide$N2
ALL_wide$I2 <- 6-ALL_wide$I2
ALL_wide$I3 <- 6-ALL_wide$I3
ALL_wide$E4 <- 6-ALL_wide$E4
ALL_wide$A4 <- 6-ALL_wide$A4
ALL_wide$C4 <- 6-ALL_wide$C4
ALL_wide$N4 <- 6-ALL_wide$N4
ALL_wide$I4 <- 6-ALL_wide$I4

#NFC-K#
ALL_wide$NF1 <- 6-ALL_wide$NF1
ALL_wide$NF4 <- 6-ALL_wide$NF4

#Regret#
ALL_wide$RE1 <- 6-ALL_wide$RE1

#Create scores of relevant questionnaire items
Extraversion<-data.frame(ALL_wide$E1,ALL_wide$E2, ALL_wide$E3, ALL_wide$E4)
ALL_wide$ExtraScore<-(ALL_wide$E1+ALL_wide$E2+ALL_wide$E3+ALL_wide$E4)/4

Agreeableness<-data.frame(ALL_wide$A1,ALL_wide$A2, ALL_wide$A3, ALL_wide$A4)
ALL_wide$AgreeScore<-(ALL_wide$A1+ALL_wide$A2+ALL_wide$A3+ALL_wide$A4)/4

Conscientiousness<-data.frame(ALL_wide$C1,ALL_wide$C2, ALL_wide$C3, ALL_wide$C4)
ALL_wide$ConscientScore<-(ALL_wide$C1+ALL_wide$C2+ALL_wide$C3+ALL_wide$C4)/4

Neuroticism<-data.frame(ALL_wide$N1,ALL_wide$N2, ALL_wide$N3, ALL_wide$N4)
ALL_wide$NeuroScore<-(ALL_wide$N1+ALL_wide$N2+ALL_wide$N3+ALL_wide$N4)/4

Intellect<-data.frame(ALL_wide$I1,ALL_wide$I2, ALL_wide$I3, ALL_wide$I4)
ALL_wide$IScore<-(ALL_wide$I1+ALL_wide$I2+ALL_wide$I3+ALL_wide$I4)/4

NFC<-data.frame(ALL_wide$NF1,ALL_wide$NF2, ALL_wide$NF3, ALL_wide$NF4)
ALL_wide$NFScore<-(ALL_wide$NF1+ALL_wide$NF2+ALL_wide$NF3+ALL_wide$NF4)/4

React<-data.frame(ALL_wide$R1,ALL_wide$R2, ALL_wide$R3, ALL_wide$R4,ALL_wide$R5,ALL_wide$R6,ALL_wide$R7,ALL_wide$R8,ALL_wide$R9,ALL_wide$R10,ALL_wide$R11,ALL_wide$R12)
ALL_wide$ReactScore<-(ALL_wide$R1+ALL_wide$R2+ALL_wide$R3+ALL_wide$R4+ALL_wide$R5+ALL_wide$R6+ALL_wide$R7+ALL_wide$R8+ALL_wide$R9+ALL_wide$R10+ALL_wide$R11+ALL_wide$R12)/12

Regret<-data.frame(ALL_wide$RE1,ALL_wide$RE2,ALL_wide$RE3,ALL_wide$RE4,ALL_wide$RE5)
ALL_wide$RegretScore<-(ALL_wide$RE1+ALL_wide$RE2+ALL_wide$RE3+ALL_wide$RE4+ALL_wide$RE5)/5

# Generate Summary Statistics in Table 2 ----------------------------------
#Note Treatment variable names differ to names in text
# NO DEFAULT = ACTIVE
# WEAK DEFAULT = DEFAULT
# STRONG DEFAULT = DEFAULT_str
# CONTRO INCOME all matchings = CONTROL-INC
# CONTROL INCOME (NO DEFAULT matching) = CACTIVE
# CONTROL INCOME (WEAK DEFAULT matching) = CDEFAULT
# CONTROL INCOME (STRONG DEFAULT matching) = CONTROL_str
#CONTROL PASSIVE GIVING all matching = CONTROL-ALT
# CONTROL PASSIVE GIVING (NO DEFAULT matching) = CONTROLGAC
# CONTROL PASSIVE GIVING (WEAK DEFAULT matching) = CONTROLGDE
# CONTROL PASSIVE GIVING (STRONG DEFAULT matching) = CONTROLG_str_ALT

#DG I giving
subTreatmentsDGI<-subset(ALL_wide, subset = Treatment %in% c("ACTIVE","DEFAULT","DEFAULT_str"))
by(data=subTreatmentsDGI$Giving,INDICES=subTreatmentsDGI$Treatment,FUN=stat.desc)
#DG II giving
by(data=ALL_wide$GivingDG,INDICES=ALL_wide$Treatment_match,FUN=stat.desc)

#Average payment in experiment
mean(ALL_wide$Profit)

# Tests: WEAK DEFAULT, STRONG DEFAULT, CONTROL conditions, Spillovers -------------------------
#WEAK DEFAULT effect
subACTIVEDEFAULT<-subset(ALL_wide, subset = Treatment %in% c("ACTIVE","DEFAULT"))
t.test(Giving~Treatment,data=subACTIVEDEFAULT, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(Giving~Treatment,data=subACTIVEDEFAULT, alternative = c("two.sided"), var.equal = TRUE)

#Proportions giving exactly 100
CrossTable(subACTIVEDEFAULT$Treatment,subACTIVEDEFAULT$Giving,fisher=TRUE,chisq=TRUE,expected=TRUE,sresid=TRUE,digits=2,format="SPSS")
prop.test(x = c(15, 6), n = c(129, 129),alternative = c("two.sided"))

#Proportions giving exactly 0
prop.test(x = c(32, 32), n = c(129, 129),alternative = c("two.sided"))

#WEAK DEFAULT effect for giving > 0
subGivingACTIVEDEFAULT<-subset(ALL_wide,subset = Treatment %in% c("ACTIVE","DEFAULT") & Giving>0)
t.test(Giving~Treatment,data=subGivingACTIVEDEFAULT, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(Giving~Treatment,data=subGivingACTIVEDEFAULT, alternative = c("two.sided"), var.equal = TRUE)

#WEAK DEFAULT spillover
t.test(GivingDG~Treatment,data=subACTIVEDEFAULT, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(GivingDG~Treatment,data=subACTIVEDEFAULT, alternative = c("two.sided"), var.equal = TRUE)

#STRONG DEFAULT effect
subACTIVEDEFAULT_str<-subset(ALL_wide, subset = Treatment %in% c("ACTIVE","DEFAULT_str"))
subDEFAULT_weak_str<-subset(ALL_wide, subset = Treatment %in% c("DEFAULT","DEFAULT_str"))
t.test(Giving~Treatment,data=subACTIVEDEFAULT_str, alternative = c("two.sided"), var.equal = TRUE)
t.test(Giving~Treatment,data=subDEFAULT_weak_str, alternative = c("two.sided"), var.equal = TRUE)

wilcox.test(Giving~Treatment,data=subACTIVEDEFAULT_str, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(Giving~Treatment,data=subDEFAULT_weak_str, alternative = c("two.sided"), var.equal = TRUE)

#Proportions giving exactly 100
CrossTable(subACTIVEDEFAULT_str$Treatment,subACTIVEDEFAULT_str$Giving,fisher=TRUE,chisq=TRUE,expected=TRUE,sresid=TRUE,digits=2,format="SPSS")
CrossTable(subDEFAULT_weak_str$Treatment,subDEFAULT_weak_str$Giving,fisher=TRUE,chisq=TRUE,expected=TRUE,sresid=TRUE,digits=2,format="SPSS")
prop.test(x = c(6, 64), n = c(129, 129),alternative = c("two.sided"))
prop.test(x = c(15, 64), n = c(129, 129),alternative = c("two.sided"))

#Proportions giving exactly 0, NO DEFAULT and DEFAULT equal no of 0 (=32)
prop.test(x = c(32, 29), n = c(129, 128),alternative = c("two.sided"))


#STRONG DEFAULT effect for giving > 0
subGivingACTIVEDEFAULT_str<-subset(ALL_wide,subset = Treatment %in% c("ACTIVE","DEFAULT_str") & Giving>0)
subGivingDEFAULT_weak_str<-subset(ALL_wide,subset = Treatment %in% c("DEFAULT","DEFAULT_str") & Giving>0)
t.test(Giving~Treatment,data=subGivingACTIVEDEFAULT_str, alternative = c("two.sided"), var.equal = TRUE)
t.test(Giving~Treatment,data=subGivingDEFAULT_weak_str, alternative = c("two.sided"), var.equal = TRUE)

wilcox.test(Giving~Treatment,data=subGivingACTIVEDEFAULT_str, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(Giving~Treatment,data=subGivingDEFAULT_weak_str, alternative = c("two.sided"), var.equal = TRUE)

#STRONG DEFAULT spillover
t.test(GivingDG~Treatment,data=subACTIVEDEFAULT_str, alternative = c("two.sided"), var.equal = TRUE)
t.test(GivingDG~Treatment,data=subDEFAULT_weak_str, alternative = c("two.sided"), var.equal = TRUE)

wilcox.test(GivingDG~Treatment,data=subACTIVEDEFAULT_str, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(GivingDG~Treatment,data=subDEFAULT_weak_str, alternative = c("two.sided"), var.equal = TRUE)

#CONTROL conditions spillover
subACTIVE_CACTIVE<-subset(ALL_wide, subset = Treatment_match %in% c("ACTIVE","CACTIVE"))
t.test(GivingDG~Treatment_match, data=subACTIVE_CACTIVE, alternative = c("two.sided"), var.equal = TRUE)
wilcox.test(GivingDG~Treatment_match, data=subACTIVE_CACTIVE, alternative = c("two.sided"), var.equal = TRUE)

subACTIVE_CONTROLGAC<-subset(ALL_wide, subset = Treatment_match %in% c("ACTIVE","CONTROLGAC"))
t.test(GivingDG~Treatment_match, data=subACTIVE_CONTROLGAC, alternative = c("two.sided"),var.equal = TRUE)
wilcox.test(GivingDG~Treatment_match, data=subACTIVE_CONTROLGAC, alternative = c("two.sided"),var.equal = TRUE)

subWEAKDEFAULT_CDEFAULT<-subset(ALL_wide, subset = Treatment_match %in% c("DEFAULT","CDEFAULT"))
t.test(GivingDG~Treatment_match, data=subWEAKDEFAULT_CDEFAULT, alternative = c("two.sided"),var.equal = TRUE)
wilcox.test(GivingDG~Treatment_match, data=subWEAKDEFAULT_CDEFAULT, alternative = c("two.sided"),var.equal = TRUE)

subWEAKDEFAULT_CONTROLGDE<-subset(ALL_wide, subset = Treatment_match %in% c("DEFAULT","CONTROLGDE"))
t.test(GivingDG~Treatment_match, data=subWEAKDEFAULT_CONTROLGDE, alternative = c("two.sided"),var.equal = TRUE)
wilcox.test(GivingDG~Treatment_match, data=subWEAKDEFAULT_CONTROLGDE, alternative = c("two.sided"),var.equal = TRUE)

subSTRONGDEFAULT_CONTROL_str<-subset(ALL_wide, subset = Treatment_match %in% c("DEFAULT_str","CONTROL_str"))
t.test(GivingDG~Treatment_match, data=subSTRONGDEFAULT_CONTROL_str, alternative = c("two.sided"),var.equal = TRUE)
wilcox.test(GivingDG~Treatment_match, data=subSTRONGDEFAULT_CONTROL_str, alternative = c("two.sided"),var.equal = TRUE)

subSTRONGDEFAULT_CONTROL_str_ALT<-subset(ALL_wide, subset = Treatment_match %in% c("DEFAULT_str","CONTROL_str_ALT"))
t.test(GivingDG~Treatment_match, data=subSTRONGDEFAULT_CONTROL_str_ALT, alternative = c("two.sided"),var.equal = TRUE)
wilcox.test(GivingDG~Treatment_match, data=subSTRONGDEFAULT_CONTROL_str_ALT, alternative = c("two.sided"),var.equal = TRUE)


# Regression Models in Table 3 --------------------------------------------
#check relevant treatments
subALLwide<-subset(ALL_wide, subset = Treatment_match %in% c("ACTIVE","DEFAULT","CACTIVE","CDEFAULT","CONTROLGDE","CONTROLGAC","CONTROL_str","CONTROL_str_ALT","DEFAULT_str"))
subALLwide$Treatment<-factor(subALLwide$Treatment, c("ACTIVE","DEFAULT","DEFAULT_str","CONTROL-INC","CONTROL-ALT"))

#check number of observations, n=678
nrow(subALLwide)
#mean center Income before DGII
subALLwide$Inc_t1z<-scale(subALLwide$Inc_t1)

#OLS
OLSt2_simple_full<-lm(GivingDG~Inc_t1z*Treatment,data=subALLwide)
summary(OLSt2_simple_full)
covfull<- vcovHC(OLSt2_simple_full, type = "HC3")
robust_se_OLSt2_simple_full <- sqrt(diag(covfull))
logLik(OLSt2_simple_full)

#Wald contrasts OLS
linearHypothesis(OLSt2_simple_full, "TreatmentDEFAULT = TreatmentCONTROL-INC")
linearHypothesis(OLSt2_simple_full, "TreatmentDEFAULT = TreatmentCONTROL-ALT")
linearHypothesis(OLSt2_simple_full, "TreatmentDEFAULT_str = TreatmentCONTROL-INC")
linearHypothesis(OLSt2_simple_full, "TreatmentDEFAULT_str = TreatmentCONTROL-ALT")
linearHypothesis(OLSt2_simple_full, "TreatmentDEFAULT_str = TreatmentDEFAULT")

#Footnote 10
linearHypothesis(OLSt2_simple_full, "Inc_t1z+Inc_t1z:TreatmentCONTROL-INC = 0")
linearHypothesis(OLSt2_simple_full, "Inc_t1z+Inc_t1z:TreatmentCONTROL-ALT = 0")

#LPM
subALLwide$GivingDG.01<-as.numeric(subALLwide$GivingDG>0)
t2OLS<- lm(GivingDG.01~Inc_t1z*Treatment, subALLwide)
summary(t2OLS)
covfull<- vcovHC(t2OLS, type = "HC3")
robust_se_t2OLS <- sqrt(diag(covfull))
logLik(t2OLS)

#Wald contrasts LPM
linearHypothesis(t2OLS, "TreatmentDEFAULT_str = TreatmentDEFAULT")
linearHypothesis(t2OLS, "TreatmentDEFAULT_str = TreatmentCONTROL-INC")
linearHypothesis(t2OLS, "TreatmentDEFAULT_str = TreatmentCONTROL-ALT")

#gamma-GLM
subALLwide$non_zero<-ifelse(subALLwide$GivingDG>0,1,0)
Gammalt2_simple_full<-glm(GivingDG~Inc_t1z*Treatment, data=subset(subALLwide, non_zero==1), family = Gamma(link = log))
summary(Gammalt2_simple_full)
covfull<- vcovHC(Gammalt2_simple_full, type = "HC3")
robust_se_Gammalt2_simple_full <- sqrt(diag(covfull))
logLik(Gammalt2_simple_full)

#Wald contrasts gamma_GLM
linearHypothesis(Gammalt2_simple_full, "TreatmentDEFAULT_str = TreatmentCONTROL-INC")
linearHypothesis(Gammalt2_simple_full, "TreatmentDEFAULT_str = TreatmentCONTROL-ALT")
linearHypothesis(Gammalt2_simple_full, "TreatmentDEFAULT_str = TreatmentDEFAULT")

#Produce Table 3 without special format
stargazer(OLSt2_simple_full,t2OLS,Gammalt2_simple_full, se=list(robust_se_OLSt2_simple_full, robust_se_t2OLS,robust_se_Gammalt2_simple_full), type="latex")

# Figure 1 ----------------------------------------------------------------
#function to display data and 95% CIs
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}

#make data ready for Figure 1
subACTIVEDEFAULTall<-subset(ALL_wide, subset = Treatment %in% c("ACTIVE","DEFAULT","DEFAULT_str"))
subACTIVEDEFAULTallse <- summarySE(subACTIVEDEFAULTall, measurevar="Giving", groupvars=c("Treatment"))
subACTIVEDEFAULTallse
subACTIVEDEFAULTseallDG <- summarySE(subACTIVEDEFAULTall, measurevar="GivingDG", groupvars=c("Treatment"))
subACTIVEDEFAULTseallDG

#left hand part of Figure 1
Charity_Stage<-ggplot(subACTIVEDEFAULTallse,aes(x=Treatment,y=Giving ,fill=Treatment))
Charity_Stage<-Charity_Stage+stat_summary(fun.y=mean,geom="bar",colour="black",alpha=0.5, position=position_dodge(0.95))+geom_errorbar(aes(ymin=Giving-se, ymax=Giving+se),width=0.05,position=position_dodge(0.95))+labs(x="",y="Mean Donation to Charity [points]")+theme_bw()+scale_fill_manual(values=c("ACTIVE"="grey20","DEFAULT"="grey50","DEFAULT_str"="grey80"),name="",breaks=c("ACTIVE", "DEFAULT weak","DEFAULT strong"),labels=c("ACTIVE"="NO DEFAULT","DEFAULT"="WEAK DEFAULT", "DEFAULT_str"="STRONG DEFAULT"))+ggtitle("Panel A: Dictator Stage I")+theme(plot.title = element_text(size=11, face="bold", vjust=1.5))+theme(axis.title.x = element_text(color="grey10", vjust=-0.35,size=18),axis.title.y = element_text(color="grey10" , vjust=0.35, size=18))+scale_y_continuous(limits=c(0, 80),breaks=seq(0,70,10))+theme(plot.title = element_text(face="bold", size=20,margin = margin(10, 0, 10, 0),hjust = 0,))+annotate("text", x = 1, y = 15, label = "?=27.44", fontface="bold",size=6,color="black")+annotate("text", x = 2, y = 15, label = "?=34.26", fontface="bold",size=6, color="black")+annotate("text", x = 3, y = 15, label = "?=58.98", fontface="bold",size=6, color="black")+annotate("text", x = 1, y = 70, label = "n=129", fontface="bold",size=6,color="black")+annotate("text", x = 2, y = 70, label = "n=129", fontface="bold",size=6,color="black")+annotate("text", x = 3, y = 70, label = "n=128", fontface="bold",size=6,color="black")+geom_vline(xintercept = 1.5)+geom_vline(xintercept = 2.5)+guides(fill=FALSE)+scale_x_discrete(labels=c("ACTIVE" = "NO DEFAULT","DEFAULT"="WEAK DEFAULT","DEFAULT_str"="STRONG DEFAULT"))+theme(axis.text.x = element_text(size=18))
Charity_Stage

#right hand part of Figure 1
Dictator_Stage<-ggplot(subACTIVEDEFAULTseallDG,aes(x=Treatment,y=GivingDG ,fill=Treatment))
Dictator_Stage<-Dictator_Stage+stat_summary(fun.y=mean,geom="bar",colour="black",alpha=0.5, position=position_dodge(0.95))+geom_errorbar(aes(ymin=GivingDG-se, ymax=GivingDG+se),width=0.05,position=position_dodge(0.95))+labs(x="",y="Mean Giving to Recipient [points]")+theme_bw()+scale_fill_manual(values=c("ACTIVE"="grey20","DEFAULT"="grey50","DEFAULT_str"="grey80"),name="",breaks=c("ACTIVE", "DEFAULT","DEFAULT_str"))+ggtitle("Panel B: Dictator Stage II")+theme(plot.title = element_text(size=11, face="bold", vjust=1.5))+theme(axis.title.x = element_text(color="grey10", vjust=-0.35,size=18),axis.title.y = element_text(color="grey10" , vjust=0.35,size=18))+scale_y_continuous(limits=c(0, 80),breaks=seq(0,70,10))+theme(plot.title = element_text(face="bold", size=20,margin = margin(10, 0, 10, 0),hjust = 1,))+annotate("text", x = 1, y = 15, label = "?=35.89", fontface="bold",size=6,color="black")+annotate("text", x = 2, y = 15, label = "?=39.69", fontface="bold",size=6, color="black")+annotate("text", x = 3, y = 15, label = "?=40.94", fontface="bold",size=6,color="black")+annotate("text", x = 1, y = 70, label = "n=129", fontface="bold",size=6,color="black")+annotate("text", x = 2, y = 70, label = "n=129", fontface="bold",size=6,color="black")+annotate("text", x = 3, y = 70, label = "n=128", fontface="bold",size=6,color="black")+geom_vline(xintercept = 1.5)+geom_vline(xintercept = 2.5)+guides(fill=FALSE)+scale_x_discrete(labels=c("ACTIVE" = "NO DEFAULT","DEFAULT"="WEAK DEFAULT","DEFAULT_str"="STRONG DEFAULT"))+theme(axis.text.x = element_text(size=18))
Dictator_Stage

#export Figure 1 to working directory
tiff(filename="Figure1.tiff",width=400, height=200, units='mm',res=150)
grid.arrange(Charity_Stage,Dictator_Stage, ncol = 2, nrow=1)
dev.off()

# Appendix: Generate Sample Characteristics in Table A1 -----------------------------
by(data=ALL_wide$age,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$age)
table_gender<-table(ALL_wide$gender, ALL_wide$Treatment)
table_gender
table_income<-table(ALL_wide$own_inc, ALL_wide$Treatment)
table_income
table_educ<-table(ALL_wide$own_educ,ALL_wide$Treatment)
table_educ
by(data=ALL_wide$ExtraScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$ExtraScore)
by(data=ALL_wide$AgreeScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$AgreeScore)
by(data=ALL_wide$ConscientScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$ConscientScore)
by(data=ALL_wide$NeuroScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$NeuroScore)
by(data=ALL_wide$IScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$IScore)
by(data=ALL_wide$NFScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$NFScore)
by(data=ALL_wide$ReactScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$ReactScore)
by(data=ALL_wide$RegretScore,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$RegretScore)
by(data=ALL_wide$iq,INDICES=ALL_wide$Treatment,FUN=stat.desc)
mean(ALL_wide$iq)
# Appendix: Matching Procedure Incomes ------------------------------------
#KS-Tests
subACTIVE<-subset(ALL_wide, subset = Treatment_match %in% c("ACTIVE"))
subCACTIVE<-subset(ALL_wide, subset = Treatment_match %in% c("CACTIVE"))
subCONTROLGAC<-subset(ALL_wide, subset = Treatment_match %in% c("CONTROLGAC"))
subDEFAULT<-subset(ALL_wide, subset = Treatment_match %in% c("DEFAULT"))
subCDEFAULT<-subset(ALL_wide, subset = Treatment_match %in% c("CDEFAULT"))
subCONTROLGDE<-subset(ALL_wide, subset = Treatment_match %in% c("CONTROLGDE"))
subDEFAULTstr<-subset(ALL_wide, subset = Treatment %in% c("DEFAULT_str"))
subCONTROL_str<-subset(ALL_wide, subset = Treatment_match %in% c("CONTROL_str"))
subCONTROL_str_ALT<-subset(ALL_wide, subset = Treatment_match %in% c("CONTROL_str_ALT"))

ks.test(subACTIVE$Inc_t1,subCACTIVE$Inc_t1)
ks.test(subACTIVE$Inc_t1,subCONTROLGAC$Inc_t1)
ks.test(subDEFAULT$Inc_t1,subCDEFAULT$Inc_t1)
ks.test(subDEFAULT$Inc_t1,subCONTROLGDE$Inc_t1)
ks.test(subDEFAULTstr$Inc_t1,subCONTROL_str$Inc_t1)
ks.test(subDEFAULTstr$Inc_t1,subCONTROL_str_ALT$Inc_t1)

# #Appendix: Charitable Giving Sums ---------------------------------------
#NO DEFAULT / WEAK DEFAULT
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesAI,FUN=stat.desc)
#sum 163 CHF  an Amnesty International
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesAidsHilfe,FUN=stat.desc)
#sum 32 CHF an Aids-Hilfe
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesCaritas,FUN=stat.desc)
#sum 95 CHF an Caritas
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesKrebsliga,FUN=stat.desc)
#sum 131 CHF an Krebsliga
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesProJuv,FUN=stat.desc)
#sum 34 CHF an Pro Juventute
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesProNatura,FUN=stat.desc)
#sum 60 CHF an Pro Natura
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesSRK,FUN=stat.desc)
#sum 107 CHF an SRK
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesSL,FUN=stat.desc)
#sum 19 CHF an Sitftung Landschaftschutz
by(data=subACTIVEDEFAULT$Giving,INDICES=subACTIVEDEFAULT$YesWWF,FUN=stat.desc)
#sum 155 CHF an WWF

#CONTROL-ALT including random picks
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesAI,FUN=stat.desc)
#sum 80 CHF  an Amnesty International
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesAidsHilfe,FUN=stat.desc)
#sum 7 CHF an Aids-Hilfe
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesCaritas,FUN=stat.desc)
#sum 20 CHF an Caritas
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesKrebsliga,FUN=stat.desc)
#sum 40 CHF an Krebsliga
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesProJuv,FUN=stat.desc)
#sum 32 CHF an Pro Juventute
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesProNatura,FUN=stat.desc)
#sum 6 CHF an Pro Natura
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesSRK,FUN=stat.desc)
#sum 32 CHF an SRK
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesSL,FUN=stat.desc)
#sum 5 CHF an Sitftung Landschaftschutz
by(data=subCONTROL-ALT$Giving,INDICES=subCONTROL-ALT$YesWWF,FUN=stat.desc)
#sum 70 CHF an WWF

#AI 243 CHF
#AidsHilfe 39 CHF
#Caritas 115 CHF
#Krebsliga 171 CHF
#ProJuv 66 CHF
#ProNat 66 CHF
#SRK 139 CHF
#SL 24 CHF
# WWF 225

#STRONG DEFAULT

by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesAI,FUN=stat.desc)
#sum 149 CHF  an Amnesty International
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesAidsHilfe,FUN=stat.desc)
#sum 57 CHF an Aids-Hilfe
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesCaritas,FUN=stat.desc)
#sum 118 CHF an Caritas
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesKrebsliga,FUN=stat.desc)
#sum 117 CHF an Krebsliga
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesProJuv,FUN=stat.desc)
#sum 42 CHF an Pro Juventute
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesProNatura,FUN=stat.desc)
#sum 61 CHF an Pro Natura
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesSRK,FUN=stat.desc)
#sum 131 CHF an SRK
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesSL,FUN=stat.desc)
#sum 0 CHF an Stiftung Landschaftschutz
by(data=subDEFAULTstr$Giving,INDICES=subDEFAULTstr$YesWWF,FUN=stat.desc)
#sum 80 CHF an WWF

#CONTROL-ALT including random picks
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesAI,FUN=stat.desc)
#sum 58 CHF  an Amnesty International
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesAidsHilfe,FUN=stat.desc)
#sum 10 CHF an Aids-Hilfe
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesCaritas,FUN=stat.desc)
#sum 2 CHF an Caritas
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesKrebsliga,FUN=stat.desc)
#sum 81 CHF an Krebsliga
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesProJuv,FUN=stat.desc)
#sum 27 CHF an Pro Juventute
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesProNatura,FUN=stat.desc)
#sum 49 CHF an Pro Natura
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesSRK,FUN=stat.desc)
#sum 25 CHF an SRK
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesSL,FUN=stat.desc)
#sum 10 CHF an Stiftung Landschaftschutz
by(data=subCONTROL_str_ALT$Giving,INDICES=subCONTROL_str_ALT$YesWWF,FUN=stat.desc)
#sum 50 CHF an WWF

#AI  207 CHF
#AidsHilfe 67 CHF
#Caritas  120 CHF
#Krebsliga  198 CHF
#ProJuv  69 CHF
#ProNat 110 CHF
#SRK 156 CHF
#SL  10 CHF
# WWF 130 CHF 

#Total 2155 CHF






